<?php
namespace FiloBlu\Countdown\Block\Adminhtml\Countdown;

class Edit extends \Magento\Backend\Block\Widget\Form\Container
{
    /**
     * Core registry
     *
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry = null;

    /**
     * @param \Magento\Backend\Block\Widget\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Widget\Context $context,
        \Magento\Framework\Registry $registry,
        array $data = []
    )
    {

        $this->_coreRegistry = $registry;
        parent::__construct($context, $data);
    }

    /**
     * Initialize store edit block
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_objectId = 'id';
        $this->_blockGroup = 'FiloBlu_Countdown';
        $this->_controller = 'adminhtml_countdown';

        parent::_construct();

        if ($this->_isAllowedAction('FiloBlu_Countdown::config')) {
            $this->buttonList->update('save', 'label', __('Save'));
            $this->buttonList->add(
                'saveandcontinue',
                [
                    'label' => __('Save and Continue Edit'),
                    'class' => 'save',
                    'data_attribute' => [
                        'mage-init' => [
                            'button' => ['event' => 'saveAndContinueEdit', 'target' => '#edit_form'],
                        ],
                    ]
                ],
                -100
            );
           
        } else {
            $this->buttonList->remove('save');
        }

        if ($this->_isAllowedAction('FiloBlu_Countdown::config')) {
            $this->buttonList->update('delete', 'label', __('Delete'));

            $storeId = $this->getRequest()->getParam('store',0);

            if ($storeId != 0 && $this->_coreRegistry->registry('filoblu_countdown_translations')->getId()) {
                $this->addButton('delete_translation', [
                    'label' => __('Delete Translation'),
                    'class' => 'delete',
                    'onclick' => 'deleteConfirm(\'Are you sure you want to delete this translation ?\', \'' . $this->getUrl('filoblucountdownadmin/*/delete',
                            [
                                'id' => $this->getRequest()->getParam('id'),
                                'store' => $storeId,
                            ]) . '\')',
                ], 0, 30);
            }

        } else {
            $this->buttonList->remove('delete');
        }

        $this->buttonList->remove('reset');
    }

    /**
     * Retrieve text for header element depending on loaded store
     *
     * @return \Magento\Framework\Phrase
     */
    public function getHeaderText()
    {
        if ($this->_coreRegistry->registry('filoblu_countdown')->getId()) {
            return __("Edit Countdown '%1'", $this->escapeHtml($this->_coreRegistry->registry('filoblu_countdown')->getCode()));
        } else {
            return __('New Countdown');
        }
    }

    /**
     * Check permission for passed action
     *
     * @param string $resourceId
     * @return bool
     */
    protected function _isAllowedAction($resourceId)
    {
        return $this->_authorization->isAllowed($resourceId);
    }

    /**
     * Getter of url for "Save and Continue" button
     * tab_id will be replaced by desired by JS later
     *
     * @return string
     */
    protected function _getSaveAndContinueUrl()
    {
        return $this->getUrl('filoblucountdownadmin/*/save', ['_current' => true, 'back' => 'edit', 'active_tab' => '']);
    }
}